%define uname dolphin

%define implot_commit 3da8bd34299965d3b0ab124df743fe3e076fa222
%define rcheevos_commit 0115d9198ff7a73ff6568027dfb948ef6031818c
%define sfml_commit 7f1162dfea4969bc17417563ac55d93b72e84c1e
#define tinygltf_commit c5641f2c22d117da7971504591a8f6a41ece488b

# switch for parallel lto
%bcond_without  lto

Name:           dolphin-emu
Epoch:          1
Version:        2506a
Release:        %mkrel 1
License:        GPLv2+
Summary:        GameCube/Wii emulator
Url:            https://dolphin-emu.org
Group:          Emulators
Source0:        https://github.com/dolphin-emu/dolphin/archive/%{version}/%{uname}-%{version}.tar.gz
# Bundled sources:
Source10:       https://github.com/epezent/implot/archive/%{implot_commit}/implot-%{implot_commit}.tar.gz
Source11:       https://github.com/RetroAchievements/rcheevos/archive/%{rcheevos_commit}/rcheevos-%{rcheevos_commit}.tar.gz
Source12:       https://github.com/SFML/SFML/archive/%{sfml_commit}/SFML-%{sfml_commit}.tar.gz
#Source14:       https://github.com/syoyo/tinygltf/archive/%{tinygltf_commit}/tinygltf-%{tinygltf_commit}.tar.gz

# Upstream patch for minizip-ng.
Patch0:         001-minizip-ng--Stop-using-compatibility-mode.patch

ExclusiveArch:  x86_64 aarch64

BuildRequires:  cmake
BuildRequires:  cmake(glslang)
BuildRequires:  cmake(Qt6)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
#BuildRequires:  cmake(SFML)
BuildRequires:  cmake(SPIRV-Tools)
BuildRequires:  cmake(VulkanLoader)
BuildRequires:  cmake(VulkanMemoryAllocator)
BuildRequires:  cubeb-devel
BuildRequires:  ffmpeg-devel
BuildRequires:  libgomp-devel
BuildRequires:  liblzo-devel
BuildRequires:  mbedtls-devel
# Could be used (with -DUSE_MGBA=ON) if code is added to use system lib.
#BuildRequires:  mgba-devel
BuildRequires:  pkgconfig(miniupnpc)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(sndio)
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(libcurl)
# Upstream is going to fork enet while trying to stay protocol compatible
# https://github.com/comex/dolphin/commit/eb234da67fef01ffbcf1ae87dce8872cbf451162
# Might want to reconsider building against the shared version in the future
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(spng)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  cmake(GTest)
BuildRequires:  cmake(TinyGLTF)
BuildRequires:  cmake(zlib-ng)
BuildRequires:  cmake(minizip-ng)

Provides:       bundled(cpp-optparse)
Provides:       bundled(expr)
Provides:       bundled(FatFs)
Provides:       bundled(FreeSurround)
Provides:       bundled(imgui)
Provides:       bundled(rangeset)
Provides:       bundled(implot)
Provides:       bundled(bochs)
Provides:       bundled(SFML)

%description
Dolphin is an emulator for two recent Nintendo video game consoles:
the GameCube and the Wii. It allows PC gamers to enjoy games for these
two consoles in full HD (1080p) with several enhancements: compatibility
with all PC controllers, turbo speed, networked multiplayer, and even more!

%prep
%autosetup -p1 -n %{uname}-%{version}

gzip -dc %{S:10} | tar -C Externals/implot/implot --strip-components=1 -xof -
gzip -dc %{S:11} | tar -C Externals/rcheevos/rcheevos --strip-components=1 -xof -
gzip -dc %{S:12} | tar -C Externals/SFML/SFML --strip-components=1 -xof -
#gzip -dc %{S:14} | tar -C Externals/tinygltf/tinygltf --strip-components=1 -xof -

# Use system tinyglf:
sed -e 's/add_subdirectory(\(.*tinygltf\)/dolphin_find_optional_system_library(TinyGLTF \1/' -i CMakeLists.txt
sed -e '/tiny_gltf.h/ s/tinygltf\///' -i Source/Core/VideoCommon/Assets/MeshAsset.cpp

%{?with_lto:
# Allow parallel linking
sed -e 's/-flto/-flto=auto/' -i CMakeLists.txt }

# Customize metainfo file
sed -e "s/\${.*DESCRIBE}/%{version}/;s/\${.*DATE}/%(date --iso-8601)/;s/\${.*REVISION}/%{version}/" \
    -e "/<custom>/,+2d" -i Flatpak/org.DolphinEmu.dolphin-emu.metainfo.xml.in

%build
export CMAKE_POLICY_VERSION_MINIMUM=3.5
%cmake -G Ninja \
       -DUSE_SYSTEM_LIBS=ON \
       -DXXHASH_FOUND=ON \
       -DENABLE_GENERIC=ON \
       -DUSE_SYSTEM_MBEDTLS=AUTO \
       -DUSE_SYSTEM_SFML=AUTO \
       -DUSE_SYSTEM_MINIZIP=AUTO \
       -DENABLE_ANALYTICS=OFF \
       -DENCODE_FRAMEDUMPS=OFF \
       -DUSE_DISCORD_PRESENCE=OFF \
       -DUSE_RETRO_ACHIEVEMENTS=OFF \
       -DUSE_MGBA=OFF \
       -DDISTRIBUTOR=%{_vendor} \
       -DBUILD_SHARED_LIBS=OFF \
       -DBUILD_STATIC_LIBS=ON \
       -DDOLPHIN_WC_REVISION=%{version} \
%{?with_lto: \
       -DENABLE_LTO=ON }
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_udevrulesdir}
install -m 0644 Data/51-usb-device.rules %{buildroot}%{_udevrulesdir}/51-dolphin-usb-device.rules
mkdir -p %{buildroot}%{_metainfodir}
install -m 0644 Flatpak/org.DolphinEmu.dolphin-emu.metainfo.xml.in \
        %{buildroot}%{_metainfodir}/org.DolphinEmu.dolphin-emu.metainfo.xml

# Fedora: - Create shell wrapper; dolphin doesn't work on wayland yet, but the QT GUI
# tries to use it. For now, force xwayland. Also fixes bodhi test warning
mv %{buildroot}/%{_bindir}/%{name} %{buildroot}/%{_bindir}/%{name}-x11
echo -e '#!/usr/bin/bash\nQT_QPA_PLATFORM=xcb %{name}-x11 "$@"' \
      > %{buildroot}/%{_bindir}/%{name}

# Thirdparty library, no need to have it installed
rm -f %{buildroot}%{_includedir}/discord_{register,rpc}.h
rm -f %{buildroot}%{_libdir}/libdiscord-rpc.a

%find_lang %{name}

%check
%cmake_build --target unittests

%files -f %{name}.lang
%doc Readme.md
%license Data/license.txt
%{_bindir}/%{name}
%{_bindir}/%{name}-nogui
%{_bindir}/%{name}-x11
%{_bindir}/dolphin-tool
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}*.6*
%{_metainfodir}/*.metainfo.xml
%{_udevrulesdir}/51-dolphin-usb-device.rules


%changelog
* Sun Jun 15 2025 aurr <aurr> 1:2506a-1.mga10
+ Revision: 2191510
- new version 2506a
+ daviddavid <daviddavid>
- rebuild for new miniupnpc 2.3.2

* Sun Dec 08 2024 daviddavid <daviddavid> 1:5.0.21460-2.mga10
+ Revision: 2122606
- rebuild for new ffmpeg 7.1

* Mon Oct 07 2024 wally <wally> 1:5.0.21460-1.mga10
+ Revision: 2104011
- new snapshot 21460

* Wed Sep 04 2024 daviddavid <daviddavid> 1:5.0.16127-4.mga10
+ Revision: 2093024
- rebuild for miniupnpc 2.2.8

* Wed Nov 09 2022 ghibo <ghibo> 1:5.0.16127-3.mga9
+ Revision: 1904994
- Fix building
+ papoteur <papoteur>
- Rebuild for fmt 9

* Mon Mar 14 2022 akien <akien> 1:5.0.16127-1.mga9
+ Revision: 1790974
- Snapshot 16127, fixes ffmpeg 5.0 support
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Tue Jan 11 2022 akien <akien> 1:5.0.15862-1.mga9
+ Revision: 1767969
- Snapshot 15862
- Unbundle libfmt

* Wed May 26 2021 akien <akien> 1:5.0.14095-1.mga9
+ Revision: 1728257
- Snapshot 5.0.14095
- Rebuild for sndio 1.8.0 with fixed SONAME

* Wed Dec 30 2020 akien <akien> 1:5.0.13178-3.mga8
+ Revision: 1665661
- Beta 5.0-13178

* Wed Dec 16 2020 umeabot <umeabot> 1:5.0.12716-3.mga8
+ Revision: 1658327
- Rebuild for new Qt5

* Tue Oct 20 2020 tv <tv> 1:5.0.12716-2.mga8
+ Revision: 1637274
- rebuild for libsndio.so.7

* Mon Oct 12 2020 akien <akien> 1:5.0.12716-1.mga8
+ Revision: 1634515
- Snapshot 5.0.12716

* Mon Aug 03 2020 daviddavid <daviddavid> 1:5.0.11824-2.mga8
+ Revision: 1610690
- rebuild for new sndio 1.7.0

* Tue Apr 28 2020 akien <akien> 1:5.0.11824-1.mga8
+ Revision: 1572762
- Snapshot 5.0.11824
- Change versioning to use snapshot number in Version (same as Fedora)
- Backport PR 8725 to update bundled soundtouch, fixes 9 CVEs (mga#26555)

* Fri Feb 21 2020 umeabot <umeabot> 1:5.0-14.9599.1.mga8.tainted
+ Revision: 1548865
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Apr 04 2019 daviddavid <daviddavid> 1:5.0-13.9599.1.mga7.tainted
+ Revision: 1385708
- Rebuild for mbedtls 2.16.1

* Tue Apr 02 2019 daviddavid <daviddavid> 1:5.0-12.9599.1.mga7.tainted
+ Revision: 1385165
- Qt5 Rebuild

* Wed Feb 13 2019 akien <akien> 1:5.0-11.9599.1.mga7.tainted
+ Revision: 1366604
- Drop support for 32-bit arches
- Snapshot r9599
- Snapshot 5.0+9413

* Thu Sep 20 2018 umeabot <umeabot> 1:5.0-10.7862.1.mga7.tainted
+ Revision: 1278042
- Mageia 7 Mass Rebuild

* Mon Aug 27 2018 daviddavid <daviddavid> 1:5.0-9.7862.1.mga7.tainted
+ Revision: 1254935
- rebuild for new miniupnpc 2.1

* Wed May 30 2018 akien <akien> 1:5.0-8.7862.1.mga7.tainted
+ Revision: 1233112
- Switch to new default Qt5 build, disable legacy wxWidgets
- Snapshot 7862

* Tue May 08 2018 kekepower <kekepower> 1:5.0-8.6436.1.mga7.tainted
+ Revision: 1227674
- Rebuild for new mbedtls

* Sun Apr 29 2018 daviddavid <daviddavid> 1:5.0-7.6436.1.mga7.tainted
+ Revision: 1223581
- add upstream patch to fix build with ffmpeg 4.0
- rebuild for new ffmpeg 4.0

* Fri Mar 09 2018 akien <akien> 1:5.0-6.6436.1.mga7.tainted
+ Revision: 1207601
- New dev snapshot 5.0+6436
- Build against bundled wxgtk 3.1, required but not available yet in mga7

* Wed Mar 07 2018 kekepower <kekepower> 1:5.0-6.mga7.tainted
+ Revision: 1207010
- Rebuild for new mbedtls

* Tue May 16 2017 neoclust <neoclust> 1:5.0-5.mga6.tainted
+ Revision: 1102000
- Rebuild against new miniupnpc

* Wed Mar 08 2017 akien <akien> 1:5.0-4.mga6.tainted
+ Revision: 1090269
- Rebuild for ffmpeg 3.2.4

* Mon Nov 14 2016 akien <akien> 1:5.0-3.mga6.tainted
+ Revision: 1067150
- Rebuild for new SFML 2.4.1

* Sun Oct 16 2016 pterjan <pterjan> 1:5.0-2.mga6
+ Revision: 1061083
- Enable generic build on non x86

* Sun Jul 10 2016 akien <akien> 1:5.0-1.mga6.tainted
+ Revision: 1040637
- Version 5.0 stable
- Improve conditional build to work with stable
- Better conditional for generic build
- Allow building nightly or stable based on a conditional macros

* Thu Jun 02 2016 daviddavid <daviddavid> 1:4.0.2-11.9366.2.mga6.tainted
+ Revision: 1019965
- rebuild for wxgtk3.0 built with GTK2

* Thu May 19 2016 akien <akien> 1:4.0.2-11.9366.1.mga6.tainted
+ Revision: 1017014
- Snapshot 9366
- MbedTLS support temporarily disabled (version too old in cauldron)

* Wed Mar 09 2016 luigiwalser <luigiwalser> 1:4.0.2-10.7082.5.mga6.tainted
+ Revision: 988647
- add patch to fix build with mbedtls

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1:4.0.2-10.7082.4.mga6.tainted
+ Revision: 918984
- rebuild for soundtouch

* Tue Oct 13 2015 fwang <fwang> 1:4.0.2-10.7082.3.mga6.tainted
+ Revision: 890227
- deal with new api of miniupnpc14
- rebuild for new miniupnpc

* Fri Aug 14 2015 ycantin <ycantin> 1:4.0.2-10.7082.2.mga6.tainted
+ Revision: 864760
- rebuild for new wxgtk built with wxRE_ADVANCED

* Thu Jul 23 2015 akien <akien> 1:4.0.2-10.7082.1.mga6.tainted
+ Revision: 856361
- Snapshot 7082
- Use system enet (to review later on as upstream is forking it)
- Add a patch to allow building against wxgtk3.0 with GTK+3
- Rebuild for wxgtk

* Sat Jun 27 2015 akien <akien> 1:4.0.2-9.6891.1.mga6.tainted
+ Revision: 846328
- New snapshot (r6891)
- Dolphin was relicensed from GPLv2 to GPLv2+

* Mon Feb 09 2015 akien <akien> 1:4.0.2-8.5406.2.mga5.tainted
+ Revision: 814393
- Rebuild for sfml 2.2

* Wed Feb 04 2015 akien <akien> 1:4.0.2-8.5406.1.mga5.tainted
+ Revision: 813385
- Enable generic (JIT-less) build on i586
- New dev snapshot 4.0-5406 (stable 4.0 branch)
- Compatible with SFML 2
- Use upstream desktop file and icons (drop custom icon sources)
- Build against system polarssl and libusb

* Wed Dec 17 2014 akien <akien> 1:4.0.2-7.mga5.tainted
+ Revision: 803764
- Rebuild for miniupnpc

* Sun Nov 16 2014 akien <akien> 1:4.0.2-6.mga5.tainted
+ Revision: 797624
- Rebuild for ffmpeg 2.4

* Sat Nov 08 2014 akien <akien> 1:4.0.2-5.mga5.tainted
+ Revision: 796094
- Rebuild for GLEW
- Improve description
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ luigiwalser <luigiwalser>
- rebuild for miniupnpc

* Tue Mar 11 2014 akien <akien> 1:4.0.2-1.mga5.tainted
+ Revision: 602469
- Bugfix version 4.0.2
- Needs wxgtk >= 2.9.3
- Adding shared BRs: lzo, miniupnpc, sdl2, soundtouch
- Remove dependency on the nonfree cg-devel

* Thu Oct 31 2013 tmb <tmb> 1:4.0-2.mga4.nonfree
+ Revision: 548351
- Mageia 4 rebuild

* Thu Oct 10 2013 dams <dams> 1:4.0-1.mga4.nonfree
+ Revision: 494507
- fix typo in specfile
+ neoclust <neoclust>
- New version

* Wed Jul 24 2013 sander85 <sander85> 1:3.5-5.mga4.nonfree
+ Revision: 457695
- Rebuild for new glew

* Tue Jul 16 2013 fwang <fwang> 1:3.5-4.mga4.nonfree
+ Revision: 454975
- rebuild for new ffmpeg

* Wed Jun 05 2013 fwang <fwang> 1:3.5-3.mga4.nonfree
+ Revision: 437475
- fix conflicts
- br sfml
- build sfml-network as static lib
- build static lib
- fix br on sfml
- force gomp
- new version 3.5
- use correct macro
- use system flags

* Thu Jan 17 2013 pterjan <pterjan> 1:3.0.802-2.mga4.nonfree
+ Revision: 389214
+ rebuild (emptylog)

* Fri Jan 11 2013 umeabot <umeabot> 1:3.0.802-2.mga3.nonfree
+ Revision: 349057
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 juancho <juancho> 1:3.0.802-1.mga3.nonfree
+ Revision: 343609
- imported package dolphin-emu


* Sun Nov 04 2012 Zombie Ryushu <ryushu@mandriva.org> 1:3.0.802-1mdv2012.0
+ Revision: 821859
- Update to git 802

* Fri Sep 07 2012 Zombie Ryushu <ryushu@mandriva.org> 1:3.0.766-1
+ Revision: 816504
- Upgrade to version 766

* Wed Mar 21 2012 Andrey Bondrov <abondrov@mandriva.org> 1:3.0.486-1
+ Revision: 785932
- imported package dolphin-emu


* Wed Mar 21 2012 Andrey Bondrov <bondrov@math.dvgu.ru> 1:3.0.486-1mdv2010.2
- Updated to git revision 486 (and use epoch to allow updates)
- Prepared to port from MIB to non-free

* Sat Jul 16 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 3.0.rev7680-69.1mib2010.2
- New version 3.0
- Updated SVN (7680) revision
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

* Fri Mar 04 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 2.0.rev7283-69mib2010.2
- Updated SVN (7039) revision
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

* Wed Feb 02 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 2.0.rev7039-69mib2010.2
- Updated SVN (7039) revision
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

* Sat Jan 29 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 2.0.rev6969-69mib2010.2
- Updated SVN (6969) revision
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

* Fri Jan 28 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 2.0.rev6946-69.1mib2010.2
- Updated SVN (6946) revision
- Added BuildRequires: libalsa-devel 
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

* Tue Jan 25 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 2.0.rev6903-69.1mib2010.2
- First build for MIB users
- MIB (Mandriva International Backport) - http://mib.pianetalinux.org/

